[freeside-commits] branch FREESIDE_4_BRANCH updated. 46aa8e84c2a28f04e5e218b7afa8dbfc9aae2ff6
Mitch Jackson
mitch at freeside.biz
Sat May 19 18:00:49 PDT 2018
The branch, FREESIDE_4_BRANCH has been updated
via 46aa8e84c2a28f04e5e218b7afa8dbfc9aae2ff6 (commit)
from 504ec7fd59d124142d98dd0539aa48ee5e8963ae (commit)
Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.
- Log -----------------------------------------------------------------
commit 46aa8e84c2a28f04e5e218b7afa8dbfc9aae2ff6
Author: Mitch Jackson <mitch at freeside.biz>
Date: Sat May 19 19:51:03 2018 -0500
RT# 78190 Fix bill summary missing taxes or fees
diff --git a/FS/FS/Template_Mixin.pm b/FS/FS/Template_Mixin.pm
index 1bae5bc40..3b8c9e136 100644
--- a/FS/FS/Template_Mixin.pm
+++ b/FS/FS/Template_Mixin.pm
@@ -1417,13 +1417,12 @@ sub print_generic {
$tax_section->{'description'} = $self->mt($tax_description);
$tax_section->{'summarized'} = '';
- if ( !grep $tax_section, @sections ) {
+ # append tax section unless it's already there
+ push @sections, $tax_section
+ unless grep {$_ eq $tax_section} @sections;
- # append it if it's not already there
- push @sections, $tax_section;
- push @summary_subtotals, $tax_section;
-
- }
+ push @summary_subtotals, $tax_section
+ unless grep {$_ eq $tax_section} @summary_subtotals;
}
-----------------------------------------------------------------------
Summary of changes:
FS/FS/Template_Mixin.pm | 11 +++++------
1 file changed, 5 insertions(+), 6 deletions(-)
More information about the freeside-commits
mailing list